@@ -11,30 +11,30 @@ import pandas as pd
 from pandas.api.types import is_numeric_dtype
 from pandas.api.types import is_string_dtype
 
-from evidently.base_metric import InputData
-from evidently.base_metric import Metric
-from evidently.calculations.data_quality import DataQualityGetPlotData
-from evidently.calculations.data_quality import FeatureQualityStats
-from evidently.calculations.data_quality import get_features_stats
-from evidently.features.non_letter_character_percentage_feature import NonLetterCharacterPercentage
-from evidently.features.OOV_words_percentage_feature import OOVWordsPercentage
-from evidently.features.text_length_feature import TextLength
-from evidently.model.widget import AdditionalGraphInfo
-from evidently.model.widget import BaseWidgetInfo
-from evidently.renderers.base_renderer import MetricRenderer
-from evidently.renderers.base_renderer import default_renderer
-from evidently.utils.data_operations import process_columns
-from evidently.utils.data_preprocessing import ColumnType
-from evidently.utils.data_preprocessing import DataDefinition
-from evidently.utils.types import Numeric
-from evidently.utils.visualizations import plot_boxes
-from evidently.utils.visualizations import plot_cat_cat_rel
-from evidently.utils.visualizations import plot_cat_feature_in_time
-from evidently.utils.visualizations import plot_distr
-from evidently.utils.visualizations import plot_distr_with_log_button
-from evidently.utils.visualizations import plot_num_feature_in_time
-from evidently.utils.visualizations import plot_num_num_rel
-from evidently.utils.visualizations import plot_time_feature_distr
+from mlopsdna.evidently.base_metric import InputData
+from mlopsdna.evidently.base_metric import Metric
+from mlopsdna.evidently.calculations.data_quality import DataQualityGetPlotData
+from mlopsdna.evidently.calculations.data_quality import FeatureQualityStats
+from mlopsdna.evidently.calculations.data_quality import get_features_stats
+from mlopsdna.evidently.features.non_letter_character_percentage_feature import NonLetterCharacterPercentage
+from mlopsdna.evidently.features.OOV_words_percentage_feature import OOVWordsPercentage
+from mlopsdna.evidently.features.text_length_feature import TextLength
+from mlopsdna.evidently.model.widget import AdditionalGraphInfo
+from mlopsdna.evidently.model.widget import BaseWidgetInfo
+from mlopsdna.evidently.renderers.base_renderer import MetricRenderer
+from mlopsdna.evidently.renderers.base_renderer import default_renderer
+from mlopsdna.evidently.utils.data_operations import process_columns
+from mlopsdna.evidently.utils.data_preprocessing import ColumnType
+from mlopsdna.evidently.utils.data_preprocessing import DataDefinition
+from mlopsdna.evidently.utils.types import Numeric
+from mlopsdna.evidently.utils.visualizations import plot_boxes
+from mlopsdna.evidently.utils.visualizations import plot_cat_cat_rel
+from mlopsdna.evidently.utils.visualizations import plot_cat_feature_in_time
+from mlopsdna.evidently.utils.visualizations import plot_distr
+from mlopsdna.evidently.utils.visualizations import plot_distr_with_log_button
+from mlopsdna.evidently.utils.visualizations import plot_num_feature_in_time
+from mlopsdna.evidently.utils.visualizations import plot_num_num_rel
+from mlopsdna.evidently.utils.visualizations import plot_time_feature_distr
 
 
 @dataclasses.dataclass
