@@ -12,20 +12,20 @@ import plotly.express as px
 import plotly.graph_objs as go
 from plotly.subplots import make_subplots
 
-from evidently.base_metric import InputData
-from evidently.base_metric import Metric
-from evidently.calculations.regression_performance import error_bias_table
-from evidently.calculations.regression_performance import error_with_quantiles
-from evidently.features.non_letter_character_percentage_feature import NonLetterCharacterPercentage
-from evidently.features.OOV_words_percentage_feature import OOVWordsPercentage
-from evidently.features.text_length_feature import TextLength
-from evidently.model.widget import AdditionalGraphInfo
-from evidently.model.widget import BaseWidgetInfo
-from evidently.renderers.base_renderer import MetricRenderer
-from evidently.renderers.base_renderer import default_renderer
-from evidently.renderers.html_widgets import header_text
-from evidently.utils.data_operations import process_columns
-from evidently.utils.data_preprocessing import DataDefinition
+from mlopsdna.evidently.base_metric import InputData
+from mlopsdna.evidently.base_metric import Metric
+from mlopsdna.evidently.calculations.regression_performance import error_bias_table
+from mlopsdna.evidently.calculations.regression_performance import error_with_quantiles
+from mlopsdna.evidently.features.non_letter_character_percentage_feature import NonLetterCharacterPercentage
+from mlopsdna.evidently.features.OOV_words_percentage_feature import OOVWordsPercentage
+from mlopsdna.evidently.features.text_length_feature import TextLength
+from mlopsdna.evidently.model.widget import AdditionalGraphInfo
+from mlopsdna.evidently.model.widget import BaseWidgetInfo
+from mlopsdna.evidently.renderers.base_renderer import MetricRenderer
+from mlopsdna.evidently.renderers.base_renderer import default_renderer
+from mlopsdna.evidently.renderers.html_widgets import header_text
+from mlopsdna.evidently.utils.data_operations import process_columns
+from mlopsdna.evidently.utils.data_preprocessing import DataDefinition
 
 
 @dataclasses.dataclass
