@@ -14,9 +14,9 @@ import numpy as np
 import pandas as pd
 import plotly.graph_objects
 
-from bmomd.nannyml._typing import Key, Metric, Result, Self
-from bmomd.nannyml.chunk import Chunker, ChunkerFactory
-from bmomd.nannyml.exceptions import (
+from mlopsdna.nannyml._typing import Key, Metric, Result, Self
+from mlopsdna.nannyml.chunk import Chunker, ChunkerFactory
+from mlopsdna.nannyml.exceptions import (
     CalculatorException,
     CalculatorNotFittedException,
     EstimatorException,
