@@ -251,14 +251,14 @@ class PeriodBasedChunker(Chunker):
     --------
     Chunk using monthly periods and providing a column name
 
-    >>> from bmomd.nannyml.chunk import PeriodBasedChunker
+    >>> from mlopsdna.nannyml.chunk import PeriodBasedChunker
     >>> df = pd.read_parquet('/path/to/my/data.pq')
     >>> chunker = PeriodBasedChunker(timestamp_column_name='observation_date', offset='M')
     >>> chunks = chunker.split(data=df)
 
     Or chunk using weekly periods
 
-    >>> from bmomd.nannyml.chunk import PeriodBasedChunker
+    >>> from mlopsdna.nannyml.chunk import PeriodBasedChunker
     >>> df = pd.read_parquet('/path/to/my/data.pq')
     >>> chunker = PeriodBasedChunker(timestamp_column_name=df['observation_date'], offset='W', minimum_chunk_size=50)
     >>> chunks = chunker.split(data=df)
@@ -324,7 +324,7 @@ class SizeBasedChunker(Chunker):
     --------
     Chunk using monthly periods and providing a column name
 
-    >>> from bmomd.nannyml.chunk import SizeBasedChunker
+    >>> from mlopsdna.nannyml.chunk import SizeBasedChunker
     >>> df = pd.read_parquet('/path/to/my/data.pq')
     >>> chunker = SizeBasedChunker(chunk_size=2000, incomplete='drop')
     >>> chunks = chunker.split(data=df)
@@ -422,7 +422,7 @@ class CountBasedChunker(Chunker):
 
     Examples
     --------
-    >>> from bmomd.nannyml.chunk import CountBasedChunker
+    >>> from mlopsdna.nannyml.chunk import CountBasedChunker
     >>> df = pd.read_parquet('/path/to/my/data.pq')
     >>> chunker = CountBasedChunker(chunk_number=100)
     >>> chunks = chunker.split(data=df)
@@ -495,7 +495,7 @@ class DefaultChunker(Chunker):
 
     Examples
     --------
-    >>> from bmomd.nannyml.chunk import DefaultChunker
+    >>> from mlopsdna.nannyml.chunk import DefaultChunker
     >>> df = pd.read_parquet('/path/to/my/data.pq')
     >>> chunker = DefaultChunker()
     >>> chunks = chunker.split(data=df)
