@@ -14,12 +14,12 @@ from sklearn.decomposition import PCA
 from sklearn.impute import SimpleImputer
 from sklearn.preprocessing import StandardScaler
 
-from bmomd.nannyml.base import AbstractCalculator, _list_missing, _split_features_by_type
-from bmomd.nannyml.chunk import Chunker
-from bmomd.nannyml.drift.multivariate.data_reconstruction.result import Result
-from bmomd.nannyml.exceptions import InvalidArgumentsException
-from bmomd.nannyml.sampling_error import SAMPLING_ERROR_RANGE
-from bmomd.nannyml.usage_logging import UsageEvent, log_usage
+from mlopsdna.nannyml.base import AbstractCalculator, _list_missing, _split_features_by_type
+from mlopsdna.nannyml.chunk import Chunker
+from mlopsdna.nannyml.drift.multivariate.data_reconstruction.result import Result
+from mlopsdna.nannyml.exceptions import InvalidArgumentsException
+from mlopsdna.nannyml.sampling_error import SAMPLING_ERROR_RANGE
+from mlopsdna.nannyml.usage_logging import UsageEvent, log_usage
 
 
 class DataReconstructionDriftCalculator(AbstractCalculator):
