@@ -15,9 +15,9 @@ import pandas as pd
 from scipy.spatial.distance import jensenshannon
 from scipy.stats import chi2_contingency, ks_2samp, kstwo, wasserstein_distance
 
-from bmomd.nannyml.base import _column_is_categorical, _remove_missing_data
-from bmomd.nannyml.chunk import Chunker
-from bmomd.nannyml.exceptions import InvalidArgumentsException, NotFittedException
+from mlopsdna.nannyml.base import _column_is_categorical, _remove_missing_data
+from mlopsdna.nannyml.chunk import Chunker
+from mlopsdna.nannyml.exceptions import InvalidArgumentsException, NotFittedException
 
 
 class Method(abc.ABC):
